@@ -29,10 +29,12 @@ class TimedeltaField(models.Field):
         if isinstance(value, int):
             return datetime.timedelta(seconds=value)
         if value == "":
-            return datetime.timedelta(0)
+            return None
         return parse(value)
     
     def get_prep_value(self, value):
+        if self.null and value == "":
+            return None
         if (value is None) or isinstance(value, (str, unicode)):
             return value
         return str(value).replace(',', '')
